==> registration-3.0.2.tar.gz: registration/tests/src/Kernel/RegistrationManagerTest.php <==
<?php

namespace Drupal\Tests\registration\Kernel;

use Drupal\node\NodeInterface;
use Drupal\registration\Entity\RegistrationInterface;
use Drupal\registration\HostEntityInterface;
use Drupal\registration\RegistrationManagerInterface;
use Drupal\Tests\registration\Traits\NodeCreationTrait;
use Drupal\Tests\registration\Traits\RegistrationCreationTrait;
use Symfony\Component\HttpFoundation\ParameterBag;

/**
 * Tests the RegistrationManager class.
 *
 * @coversDefaultClass \Drupal\registration\RegistrationManager
 *
 * @group registration
 */
class RegistrationManagerTest extends RegistrationKernelTestBase {

  use NodeCreationTrait;
  use RegistrationCreationTrait;

  /**
   * The host entity.
   *
   * @var \Drupal\registration\HostEntityInterface
   */
  protected HostEntityInterface $hostEntity;

  /**
   * The node.
   *
   * @var \Drupal\node\NodeInterface
   */
  protected NodeInterface $node;

  /**
   * The registration manager.
   *
   * @var \Drupal\registration\RegistrationManagerInterface
   */
  protected RegistrationManagerInterface $registrationManager;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $admin_user = $this->createUser();
    $this->setCurrentUser($admin_user);

    $this->node = $this->createAndSaveNode();

    $this->registrationManager = $this->container->get('registration.manager');

    $registration = $this->createRegistration($this->node);
    $registration->set('anon_mail', 'test@example.com');
    $registration->save();
    $this->hostEntity = $registration->getHostEntity();
  }

  /**
   * @covers ::getBaseRouteName
   * @covers ::getEntityFromParameters
   * @covers ::getRegistrantOptions
   * @covers ::getRegistrationEnabledEntityTypes
   * @covers ::getRoute
   * @covers ::hasRegistrationField
   * @covers ::userHasRegistrations
   */
  public function testRegistrationManager() {
    $entity_type = $this->node->getEntityType();
    $base_route_name = $this->registrationManager->getBaseRouteName($entity_type);
    $this->assertEquals('entity.node.canonical', $base_route_name);

    $parameter_bag = new ParameterBag([
      'node' => $this->node,
    ]);

    $host_entity = $this->registrationManager->getEntityFromParameters($parameter_bag, TRUE);
    $this->assertEquals($this->hostEntity->id(), $host_entity->id());
    $entity = $this->registrationManager->getEntityFromParameters($parameter_bag, FALSE);
    $this->assertEquals($this->node->id(), $entity->id());

    $settings = $this->hostEntity->getSettings();
    $list = $this->hostEntity->getRegistrationList();
    $registration = reset($list);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);

    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $registration2 = $this->createRegistration($this->node);
    $registration2->set('user_uid', 1);
    $registration2->save();

    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    // The current user (1) is already registered.
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $account = $this->createUser([], ['access registration overview']);
    $this->container->get('current_user')->setAccount($account);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $account = $this->createUser([], ['create conference registration self']);
    $this->container->get('current_user')->setAccount($account);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $account = $this->createUser([], ['create conference registration other users']);
    $this->container->get('current_user')->setAccount($account);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $account = $this->createUser([], ['create conference registration other anonymous']);
    $this->container->get('current_user')->setAccount($account);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $types = $this->registrationManager->getRegistrationEnabledEntityTypes();
    $this->assertArrayHasKey('node', $types);

    $route = $this->registrationManager->getRoute($entity_type, 'register');
    $this->assertEquals('/node/{node}/register', $route->getPath());

    $this->assertTrue($this->registrationManager->hasRegistrationField($entity_type));
    $this->assertTrue($this->registrationManager->hasRegistrationField($entity_type, 'event'));
    $user_entity_type = $this->entityTypeManager->getDefinition('user');
    $this->assertFalse($this->registrationManager->hasRegistrationField($user_entity_type));

    /** @var \Drupal\user\UserInterface $user */
    $user = $this->entityTypeManager->getStorage('user')->load(1);
    $this->assertTrue($this->registrationManager->userHasRegistrations($user));
    $this->assertFalse($this->registrationManager->userHasRegistrations($account));
  }

}

==> registration-3.1.6.tar.gz: registration/tests/src/Kernel/RegistrationManagerTest.php <==
<?php

namespace Drupal\Tests\registration\Kernel;

use Drupal\node\NodeInterface;
use Drupal\registration\Entity\RegistrationInterface;
use Drupal\registration\HostEntityInterface;
use Drupal\registration\RegistrationManagerInterface;
use Drupal\Tests\registration\Traits\NodeCreationTrait;
use Drupal\Tests\registration\Traits\RegistrationCreationTrait;
use Symfony\Component\HttpFoundation\ParameterBag;

/**
 * Tests the RegistrationManager class.
 *
 * @coversDefaultClass \Drupal\registration\RegistrationManager
 *
 * @group registration
 */
class RegistrationManagerTest extends RegistrationKernelTestBase {

  use NodeCreationTrait;
  use RegistrationCreationTrait;

  /**
   * The host entity.
   *
   * @var \Drupal\registration\HostEntityInterface
   */
  protected HostEntityInterface $hostEntity;

  /**
   * The node.
   *
   * @var \Drupal\node\NodeInterface
   */
  protected NodeInterface $node;

  /**
   * The registration manager.
   *
   * @var \Drupal\registration\RegistrationManagerInterface
   */
  protected RegistrationManagerInterface $registrationManager;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $admin_user = $this->createUser();
    $this->setCurrentUser($admin_user);

    $this->node = $this->createAndSaveNode();

    $this->registrationManager = $this->container->get('registration.manager');

    $registration = $this->createRegistration($this->node);
    $registration->set('anon_mail', 'test@example.com');
    $registration->save();
    $this->hostEntity = $registration->getHostEntity();
  }

  /**
   * @covers ::getBaseRouteName
   * @covers ::getEntityFromParameters
   * @covers ::getRegistrantOptions
   * @covers ::getRegistrationEnabledEntityTypes
   * @covers ::getRoute
   * @covers ::hasRegistrationField
   * @covers ::userHasRegistrations
   */
  public function testRegistrationManager() {
    $entity_type = $this->node->getEntityType();
    $base_route_name = $this->registrationManager->getBaseRouteName($entity_type);
    $this->assertEquals('entity.node.canonical', $base_route_name);

    $parameter_bag = new ParameterBag([
      'node' => $this->node,
    ]);

    $host_entity = $this->registrationManager->getEntityFromParameters($parameter_bag, TRUE);
    $this->assertEquals($this->hostEntity->id(), $host_entity->id());
    $entity = $this->registrationManager->getEntityFromParameters($parameter_bag, FALSE);
    $this->assertEquals($this->node->id(), $entity->id());

    $settings = $this->hostEntity->getSettings();
    $list = $this->hostEntity->getRegistrationList();
    $registration = reset($list);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);

    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $registration2 = $this->createRegistration($this->node);
    $registration2->set('user_uid', 1);
    $registration2->save();

    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    // The current user (1) is already registered.
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $account = $this->createUser(['access registration overview']);
    $this->container->get('current_user')->setAccount($account);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $account = $this->createUser(['create conference registration self']);
    $this->container->get('current_user')->setAccount($account);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $account = $this->createUser(['create conference registration other users']);
    $this->container->get('current_user')->setAccount($account);
    $options = $this->registrationManager->getRegistrantOptions($registration2, $settings);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $account = $this->createUser(['create conference registration other anonymous']);
    $this->container->get('current_user')->setAccount($account);
    $options = $this->registrationManager->getRegistrantOptions($registration, $settings);
    $this->assertArrayHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ANON, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_USER, $options);
    $this->assertArrayNotHasKey(RegistrationInterface::REGISTRATION_REGISTRANT_TYPE_ME, $options);

    $types = $this->registrationManager->getRegistrationEnabledEntityTypes();
    $this->assertArrayHasKey('node', $types);

    $route = $this->registrationManager->getRoute($entity_type, 'register');
    $this->assertEquals('/node/{node}/register', $route->getPath());

    $this->assertTrue($this->registrationManager->hasRegistrationField($entity_type));
    $this->assertTrue($this->registrationManager->hasRegistrationField($entity_type, 'event'));
    $user_entity_type = $this->entityTypeManager->getDefinition('user');
    $this->assertFalse($this->registrationManager->hasRegistrationField($user_entity_type));

    /** @var \Drupal\user\UserInterface $user */
    $user = $this->entityTypeManager->getStorage('user')->load(1);
    $this->assertTrue($this->registrationManager->userHasRegistrations($user));
    $this->assertFalse($this->registrationManager->userHasRegistrations($account));
  }

}
